@@ -277,6 +277,11 @@ https://creativecommons.org/publicdomain/zero/1.0/ .
 """
 
 from __future__ import print_function
+from future import standard_library
+standard_library.install_aliases()
+from builtins import str
+from builtins import range
+from builtins import object
 try:
     import configparser
 except ImportError:
@@ -289,7 +294,7 @@ import subprocess
 import sys
 
 
-class VersioneerConfig:
+class VersioneerConfig(object):
     """Container for Versioneer configuration parameters."""
 
 
@@ -424,6 +429,7 @@ def unique(seq):
     Implementation does not depend on `numpy`
     * borrowed from https://stackoverflow.com/a/480227
     * credit to Markus Jarderot
+      + https://www.peterbe.com/plog/uniqifiers-benchmark
     """
     seen = set()
     seen_add = seen.add
@@ -442,6 +448,12 @@ LONG_VERSION_PY['git'] = '''
 
 """Git implementation of _version.py."""
 
+from __future__ import print_function
+
+from builtins import str
+from builtins import range
+from builtins import object
+
 import errno
 import os
 import re
@@ -455,14 +467,14 @@ def get_keywords():
     # setup.py/versioneer.py will grep for the variable names, so they must
     # each be defined on a line of their own. _version.py will just call
     # get_keywords().
-    git_refnames = "$Format:%d$"
-    git_full = "$Format:%H$"
-    git_date = "$Format:%ci$"
+    git_refnames = "%(DOLLAR)sFormat:%%d%(DOLLAR)s"
+    git_full = "%(DOLLAR)sFormat:%%H%(DOLLAR)s"
+    git_date = "%(DOLLAR)sFormat:%%ci%(DOLLAR)s"
     keywords = {"refnames": git_refnames, "full": git_full, "date": git_date}
     return keywords
 
 
-class VersioneerConfig:
+class VersioneerConfig(object):
     """Container for Versioneer configuration parameters."""
 
 
@@ -472,12 +484,10 @@ def get_config():
     # _version.py
     cfg = VersioneerConfig()
     cfg.VCS = "git"
-    # cfg.style = "pep440-micro"
-    # cfg.style = "pep440-develop"
-    cfg.style = "pep440-auto"
-    cfg.tag_prefix = ""
-    cfg.parentdir_prefix = ""
-    cfg.versionfile_source = "pkgscript/_version.py"
+    cfg.style = "%(STYLE)s"
+    cfg.tag_prefix = "%(TAG_PREFIX)s"
+    cfg.parentdir_prefix = "%(PARENTDIR_PREFIX)s"
+    cfg.versionfile_source = "%(VERSIONFILE_SOURCE)s"
     cfg.verbose = False
     return cfg
 
@@ -520,20 +530,20 @@ def run_command(commands, args, cwd=None, verbose=False, hide_stderr=False,
             if e.errno == errno.ENOENT:
                 continue
             if verbose:
-                print("unable to run %s" % dispcmd)
+                print("unable to run %%s" %% dispcmd)
                 print(e)
             return None, None
     else:
         if verbose:
-            print("unable to find command, tried %s" % (commands,))
+            print("unable to find command, tried %%s" %% (commands,))
         return None, None
     stdout = p.communicate()[0].strip()
     if sys.version_info[0] >= 3:
         stdout = stdout.decode()
     if p.returncode != 0:
         if verbose:
-            print("unable to run %s (error)" % dispcmd)
-            print("stdout was %s" % stdout)
+            print("unable to run %%s (error)" %% dispcmd)
+            print("stdout was %%s" %% stdout)
         return None, p.returncode
     return stdout, p.returncode
 
@@ -558,7 +568,7 @@ def versions_from_parentdir(parentdir_prefix, root, verbose):
             root = os.path.dirname(root)  # up a level
 
     if verbose:
-        print("Tried directories %s but none started with prefix %s" %
+        print("Tried directories %%s but none started with prefix %%s" %%
               (str(rootdirs), parentdir_prefix))
     raise NotThisMethod("rootdir doesn't start with parentdir_prefix")
 
@@ -599,8 +609,8 @@ def git_versions_from_keywords(keywords, tag_prefix, verbose):
         raise NotThisMethod("no keywords at all, weird")
     date = keywords.get("date")
     if date is not None:
-        # git-2.2.0 added "%cI", which expands to an ISO-8601 -compliant
-        # datestamp. However we prefer "%ci" (which expands to an "ISO-8601
+        # git-2.2.0 added "%%cI", which expands to an ISO-8601 -compliant
+        # datestamp. However we prefer "%%ci" (which expands to an "ISO-8601
         # -like" string, which we must then edit to make compliant), because
         # it's been around since git-1.5.3, and it's too difficult to
         # discover which version we're using, or to work around using an
@@ -618,7 +628,7 @@ def git_versions_from_keywords(keywords, tag_prefix, verbose):
     tags = set([r[len(TAG):] for r in refs if r.startswith(TAG)])
     if not tags:
         # Either we're using git < 1.8.3, or there really are no tags. We use
-        # a heuristic: assume all version tags have a digit. The old git %d
+        # a heuristic: assume all version tags have a digit. The old git %%d
         # expansion behaves like git log --decorate=short and strips out the
         # refs/heads/ and refs/tags/ prefixes that would let us distinguish
         # between branches and tags. By ignoring refnames without digits, we
@@ -626,15 +636,15 @@ def git_versions_from_keywords(keywords, tag_prefix, verbose):
         # "stabilization", as well as "HEAD" and "master".
         tags = set([r for r in refs if re.search(r'\d', r)])
         if verbose:
-            print("discarding '%s', no digits" % ",".join(refs - tags))
+            print("discarding '%%s', no digits" %% ",".join(refs - tags))
     if verbose:
-        print("likely tags: %s" % ",".join(sorted(tags)))
+        print("likely tags: %%s" %% ",".join(sorted(tags)))
     for ref in sorted(tags):
         # sorting will prefer e.g. "2.0" over "2.0rc1"
         if ref.startswith(tag_prefix):
             r = ref[len(tag_prefix):]
             if verbose:
-                print("picking %s" % r)
+                print("picking %%s" %% r)
             return {"version": r,
                     "full-revisionid": keywords["full"].strip(),
                     "dirty": False, "error": None,
@@ -663,14 +673,14 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
                           hide_stderr=True)
     if rc != 0:
         if verbose:
-            print("Directory %s not under git control" % root)
+            print("Directory %%s not under git control" %% root)
         raise NotThisMethod("'git rev-parse --git-dir' returned error")
 
     # if there is a tag matching tag_prefix, this yields TAG-NUM-gHEX[-dirty]
     # if there isn't one, this yields HEX[-dirty] (no NUM)
     describe_out, rc = run_command(GITS, ["describe", "--tags", "--dirty",
                                           "--always", "--long",
-                                          "--match", "%s*" % tag_prefix],
+                                          "--match", "%%s*" %% tag_prefix],
                                    cwd=root)
     # --long was added in git-1.5.5
     if describe_out is None:
@@ -708,18 +718,18 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
         mo = re.search(r'^(.+)-(\d+)-g([0-9a-f]+)$', git_describe)
         if not mo:
             # unparseable. Maybe git-describe is misbehaving?
-            pieces["error"] = ("unable to parse git-describe output: '%s'"
-                               % describe_out)
+            pieces["error"] = ("unable to parse git-describe output: '%%s'"
+                               %% describe_out)
             return pieces
 
         # tag
         full_tag = mo.group(1)
         if not full_tag.startswith(tag_prefix):
             if verbose:
-                fmt = "tag '%s' doesn't start with prefix '%s'"
-                print(fmt % (full_tag, tag_prefix))
-            pieces["error"] = ("tag '%s' doesn't start with prefix '%s'"
-                               % (full_tag, tag_prefix))
+                fmt = "tag '%%s' doesn't start with prefix '%%s'"
+                print(fmt %% (full_tag, tag_prefix))
+            pieces["error"] = ("tag '%%s' doesn't start with prefix '%%s'"
+                               %% (full_tag, tag_prefix))
             return pieces
         pieces["closest-tag"] = full_tag[len(tag_prefix):]
 
@@ -733,7 +743,7 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
             history_search_args = ["--ancestry-path", "--first-parent"]
         distance_to_tag, rc = run_command(
             GITS, ["rev-list", "--count",] + history_search_args +
-                  ["%s..HEAD" % pieces["closest-tag"] ], cwd=root)
+                  ["%%s..HEAD" % pieces["closest-tag"] ], cwd=root)
         pieces["distance"] = int(distance_to_tag)
 
         # commit: short hex revision ID
@@ -753,7 +763,7 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
         GITS, ["merge-base", "master", "HEAD", "-a"], cwd=root)
     distance_to_master, rc = run_command(
         GITS, ["rev-list", "--count", "--ancestry-path",
-        "%s..HEAD" % merge_base_master], cwd=root)
+        "%%s..HEAD" %% merge_base_master], cwd=root)
     pieces["distance-to-master"] = int(distance_to_master)
 
     ##################################################
@@ -762,7 +772,7 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
         # TAG exists
         master_to_tag, rc = run_command(
             GITS, ["rev-list", "--count", "--ancestry-path", "--first-parent",
-                   "%s..%s" % (pieces["closest-tag"], merge_base_master) ],
+                   "%%s..%%s" % (pieces["closest-tag"], merge_base_master) ],
             cwd=root)
         pieces["master-to-tag"] = int(master_to_tag)
     else:
@@ -780,12 +790,12 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
             GITS, ["merge-base", "develop", "HEAD", "-a"], cwd=root)
         distance_to_develop, rc = run_command(
             GITS, ["rev-list", "--count", "--ancestry-path",
-            "%s..HEAD" % merge_base_develop], cwd=root)
+            "%%s..HEAD" %% merge_base_develop], cwd=root)
         pieces["develop"] = branch_develop
         pieces["distance-to-develop"] = int(distance_to_develop)
 
     # commit date: see ISO-8601 comment in git_versions_from_keywords()
-    date = run_command(GITS, ["show", "-s", "--format=%ci", "HEAD"],
+    date = run_command(GITS, ["show", "-s", "--format=%%ci", "HEAD"],
                        cwd=root)[0].strip()
     pieces["date"] = date.strip().replace(" ", "T", 1).replace(" ", "", 1)
 
@@ -812,12 +822,12 @@ def render_pep440(pieces):
         rendered = pieces["closest-tag"]
         if pieces["distance"] or pieces["dirty"]:
             rendered += plus_or_dot(pieces)
-            rendered += "%d.g%s" % (pieces["distance"], pieces["short"])
+            rendered += "%%d.g%%s" %% (pieces["distance"], pieces["short"])
             if pieces["dirty"]:
                 rendered += ".dirty"
     else:
         # exception #1
-        rendered = "0+untagged.%d.g%s" % (pieces["distance"],
+        rendered = "0+untagged.%%d.g%%s" %% (pieces["distance"],
                                           pieces["short"])
         if pieces["dirty"]:
             rendered += ".dirty"
@@ -833,10 +843,10 @@ def render_pep440_pre(pieces):
     if pieces["closest-tag"]:
         rendered = pieces["closest-tag"]
         if pieces["distance"]:
-            rendered += ".post.dev%d" % pieces["distance"]
+            rendered += ".post.dev%%d" %% pieces["distance"]
     else:
         # exception #1
-        rendered = "0.post.dev%d" % pieces["distance"]
+        rendered = "0.post.dev%%d" %% pieces["distance"]
     return rendered
 
 
@@ -853,17 +863,17 @@ def render_pep440_post(pieces):
     if pieces["closest-tag"]:
         rendered = pieces["closest-tag"]
         if pieces["distance"] or pieces["dirty"]:
-            rendered += ".post%d" % pieces["distance"]
+            rendered += ".post%%d" %% pieces["distance"]
             if pieces["dirty"]:
                 rendered += ".dev0"
             rendered += plus_or_dot(pieces)
-            rendered += "g%s" % pieces["short"]
+            rendered += "g%%s" %% pieces["short"]
     else:
         # exception #1
-        rendered = "0.post%d" % pieces["distance"]
+        rendered = "0.post%%d" %% pieces["distance"]
         if pieces["dirty"]:
             rendered += ".dev0"
-        rendered += "+g%s" % pieces["short"]
+        rendered += "+g%%s" %% pieces["short"]
     return rendered
 
 
@@ -878,12 +888,12 @@ def render_pep440_old(pieces):
     if pieces["closest-tag"]:
         rendered = pieces["closest-tag"]
         if pieces["distance"] or pieces["dirty"]:
-            rendered += ".post%d" % pieces["distance"]
+            rendered += ".post%%d" %% pieces["distance"]
             if pieces["dirty"]:
                 rendered += ".dev0"
     else:
         # exception #1
-        rendered = "0.post%d" % pieces["distance"]
+        rendered = "0.post%%d" %% pieces["distance"]
         if pieces["dirty"]:
             rendered += ".dev0"
     return rendered
@@ -899,14 +909,14 @@ def render_pep440_micro(pieces):
     """
     if pieces["closest-tag"]:
         rendered = pieces["closest-tag"]
-        rendered += ".%d" % pieces["distance"]
+        rendered += ".%%d" %% pieces["distance"]
         if pieces["dirty"]:
             rendered += plus_or_dot(pieces)
-            rendered += "g%s" % pieces["short"]
+            rendered += "g%%s" %% pieces["short"]
             rendered += ".dirty"
     else:
         # exception #1
-        rendered = "0+untagged.%d.g%s" % (pieces["distance"],
+        rendered = "0+untagged.%%d.g%%s" %% (pieces["distance"],
                                           pieces["short"])
         if pieces["dirty"]:
             rendered += ".dirty"
@@ -930,14 +940,14 @@ def render_pep440_develop(pieces):
         # distance_merge_to_tag = (pieces["distance"] - distance_to_merge)
         distance_merge_to_tag = pieces["master-to-tag"]
         if (distance_merge_to_tag > 0):
-            rendered += ".%d" % distance_merge_to_tag
-        rendered += ".post.dev%d" % distance_to_merge
+            rendered += ".%%d" %% distance_merge_to_tag
+        rendered += ".post.dev%%d" %% distance_to_merge
     else:
         # exception #1
-        rendered = "0.post.dev%d" % (pieces["distance"] - 1)
+        rendered = "0.post.dev%%d" %% (pieces["distance"] - 1)
     if pieces["dirty"]:
         rendered += plus_or_dot(pieces)
-        rendered += "g%s" % pieces["short"]
+        rendered += "g%%s" %% pieces["short"]
         rendered += ".dirty"
     return rendered
 
@@ -962,17 +972,17 @@ def render_pep440_feature(pieces):
         distance_merge_to_tag = pieces["master-to-tag"]
         distance_dev_to_merge = (distance_to_merge - distance_to_develop)
         if (distance_merge_to_tag > 0):
-            rendered += ".%d" % distance_merge_to_tag
-        rendered += ".post.dev%d" % distance_dev_to_merge
+            rendered += ".%%d" %% distance_merge_to_tag
+        rendered += ".post.dev%%d" %% distance_dev_to_merge
         rendered += plus_or_dot(pieces)
-        rendered += "g%s" % pieces["short"]
-        rendered += ".%s" % pieces["branch"]
-        rendered += ".%d" % distance_to_develop
+        rendered += "g%%s" %% pieces["short"]
+        rendered += ".%%s" %% pieces["branch"]
+        rendered += ".%%d" %% distance_to_develop
     else:
         # exception #1
-        rendered = "0.post.dev%d" % (pieces["distance"] - 1)
+        rendered = "0.post.dev%%d" %% (pieces["distance"] - 1)
         rendered += plus_or_dot(pieces)
-        rendered += "g%s" % pieces["short"]
+        rendered += "g%%s" %% pieces["short"]
     if pieces["dirty"]:
         rendered += ".dirty"
     return rendered
@@ -1013,7 +1023,7 @@ def render_git_describe(pieces):
     if pieces["closest-tag"]:
         rendered = pieces["closest-tag"]
         if pieces["distance"]:
-            rendered += "-%d-g%s" % (pieces["distance"], pieces["short"])
+            rendered += "-%%d-g%%s" %% (pieces["distance"], pieces["short"])
     else:
         # exception #1
         rendered = pieces["short"]
@@ -1033,7 +1043,7 @@ def render_git_describe_long(pieces):
     """
     if pieces["closest-tag"]:
         rendered = pieces["closest-tag"]
-        rendered += "-%d-g%s" % (pieces["distance"], pieces["short"])
+        rendered += "-%%d-g%%s" %% (pieces["distance"], pieces["short"])
     else:
         # exception #1
         rendered = pieces["short"]
@@ -1073,7 +1083,7 @@ def render(pieces, style):
     elif style == "git-describe-long":
         rendered = render_git_describe_long(pieces)
     else:
-        raise ValueError("unknown style '%s'" % style)
+        raise ValueError("unknown style '%%s'" %% style)
 
     return {"version": rendered, "full-revisionid": pieces["long"],
             "dirty": pieces["dirty"], "error": None,
